# SDG-Utilities
A library that provides a set of utilities for managing and analysing SDG data. 

## Install
To install this library:
`pip install sdgutilities`

## Pip Packages
This library is available on PyPi:
`https://pypi.org/project/sdgutilities/`

## Contact

Project Contributors:
- Luis Gonzalez Morales
- Mark Iliffe
